namespace Eco.Mods.TechTree
{
    using System.Collections.Generic;
    using System.Linq;
    using Eco.Gameplay.Components;
    using Eco.Gameplay.DynamicValues;
    using Eco.Gameplay.Items;
    using Eco.Gameplay.Players;
    using Eco.Gameplay.Skills;
    using Eco.Gameplay.Systems.TextLinks;
    using Eco.Mods.TechTree;
    using Eco.Shared.Items;
    using Eco.Shared.Localization;
    using Eco.Shared.Serialization;
    using Eco.Shared.Utils;
    using Eco.Shared.View;
    
    [Serialized]
    [Weight(300)]                                          
    public partial class LasagnaItem :
        FoodItem            
    {
        public override string FriendlyName                     { get { return "Lasagna"; } }
        public override string Description                      { get { return "A classic baked pasta dish."; } }

        private static Nutrients nutrition = new Nutrients()    { Carbs = 18, Fat = 9, Protein = 5, Vitamins = 4};
        public override float Calories                          { get { return 900; } }
        public override Nutrients Nutrition                     { get { return nutrition; } }
    }

    [RequiresSkill(typeof(BasicBakingSkill), 3)]    
    public partial class LasagnaRecipe : Recipe
    {
        public LasagnaRecipe()
        {
            this.Products = new CraftingElement[]
            {
                new CraftingElement<LasagnaItem>(),
               
            };
            this.Ingredients = new CraftingElement[]
            {
                new CraftingElement<PastaItem>(typeof(BasicBakingEfficiencySkill), 25, BasicBakingEfficiencySkill.MultiplicativeStrategy),
		new CraftingElement<TomatoItem>(typeof(BasicBakingEfficiencySkill), 25, BasicBakingEfficiencySkill.MultiplicativeStrategy),
		new CraftingElement<ScrapMeatItem>(typeof(BasicBakingEfficiencySkill), 10, BasicBakingEfficiencySkill.MultiplicativeStrategy),
            };
            this.CraftMinutes = CreateCraftTimeValue(typeof(LasagnaRecipe), Item.Get<LasagnaItem>().UILink(), 10, typeof(BasicBakingSpeedSkill)); 
            this.Initialize("Lasagna", typeof(LasagnaRecipe));
            CraftingComponent.AddRecipe(typeof(BakeryOvenObject), this);
        }
    }
}